rhg\_compute\_tools.design package
==================================

Submodules
----------

rhg\_compute\_tools.design.colors module
----------------------------------------

.. automodule:: rhg_compute_tools.design.colors
    :members:
    :undoc-members:
    :show-inheritance:

rhg\_compute\_tools.design.plotting module
------------------------------------------

.. automodule:: rhg_compute_tools.design.plotting
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: rhg_compute_tools.design
    :members:
    :undoc-members:
    :show-inheritance:
